@@ -11,7 +11,8 @@ y = Point(2, 1)
 
 print(" kernel ([2 2],[1 1]) = %.12g" % kernel(x, y))
 print(" dkernel/dx_i([2 2],[1 1]) = ", repr(kernel.partialGradient(x, y)))
-print(" d2kernel/(dx_i*dx_j)([2 2],[1 1]) = ", repr(kernel.partialHessian(x, y)))
+print(" d2kernel/(dx_i*dx_j)([2 2],[1 1]) = ", repr(
+    kernel.partialHessian(x, y)))
 
 x[0] = 0
 x[1] = 5
@@ -20,4 +21,5 @@ y[1] = 3
 
 print(" kernel ([0 5],[0 3]) = %.12g" % kernel(x, y))
 print(" dkernel/dx_i([0 5],[0 3]) = ", repr(kernel.partialGradient(x, y)))
-print(" d2kernel/(dx_i*dx_j)([0 5],[0 3]) = ", repr(kernel.partialHessian(x, y)))
+print(" d2kernel/(dx_i*dx_j)([0 5],[0 3]) = ", repr(
+    kernel.partialHessian(x, y)))
